@@ -13,6 +13,12 @@ import click
 #
 PROGRAM_NAME = "bionorm"
 CONFIG_FILE_ENVVAR = "BIONORM_CONFIG_FILE_PATH"
+FASTA_TYPES = ["fna", "fasta", "fa", "faa"]
+GFF_TYPES = ["gff", "gff3"]
+COMPRESSED_TYPES = ["gz", "bgz", "bz", "xz"]
+GENUS_CODE_LEN = 3
+SPECIES_CODE_LEN = 2
+KEY_LEN = 4
 #
 # global logger object
 #
