@@ -13,7 +13,6 @@ from sequencetools.tools.basic_fasta_stats import basic_fasta_stats
 
 # module imports
 from . import specification_checks
-from .metrics import count_gff_features
 from . import cli
 from .common import logger
 
@@ -23,6 +22,21 @@ FASTA_TYPES = ("fna", "faa", "fasta", "frn")
 GFF_TYPES = ("gff", "gff3")
 
 
+def count_gff_features(gff):
+    counts = {}
+    with Path(gff).open("r") as fopen:
+        for line in fopen:
+            if not line or line.isspace() or line.startswith("#"):  # skip comments
+                continue
+            line = line.rstrip()
+            f = line.split("\t")  # get fields
+            if f[2] not in counts:  # feature type
+                counts[f[2]] = 1
+                continue
+            counts[f[2]] += 1
+    return counts
+
+
 class Detector:
 
     """Detect datastore file inconsistencies."""
@@ -345,7 +359,7 @@ class Detector:
 @click.option("--fasta_headers", is_flag=True, help="""Check consistency of FASTA headers and GFF.""")
 @click.argument("target", nargs=1)
 def consistency(target, busco, nodes, genome_main, gene_models_main, genometools, fasta_headers):
-    """Check for consistency with Data Store standards."""
+    """Check self-consistency and consistency with standards."""
     detector = Detector(
         target,
         busco=busco,
